# InlineResponse2007

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | Record ID | 
**created_time** | **datetime** | A date timestamp in the ISO format, eg:\&quot;2018-01-01T00:00:00.000Z\&quot; | 
**fields** | **dict(str, object)** | Cell values are keyed by field ID. See Cell Values for more information on cell value response types. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

